[xiph-commits] r14300 - in trunk/ffmpeg2theora: . kino_export

j at svn.xiph.org j at svn.xiph.org
Wed Dec 12 13:14:15 PST 2007


Author: j
Date: 2007-12-12 13:14:14 -0800 (Wed, 12 Dec 2007)
New Revision: 14300

Modified:
   trunk/ffmpeg2theora/README
   trunk/ffmpeg2theora/ffmpeg2theora.1
   trunk/ffmpeg2theora/ffmpeg2theora.c
   trunk/ffmpeg2theora/kino_export/ffmpeg2theora.sh
Log:
use .ogv, fixes #1189

Modified: trunk/ffmpeg2theora/README
===================================================================
--- trunk/ffmpeg2theora/README	2007-12-12 19:44:40 UTC (rev 14299)
+++ trunk/ffmpeg2theora/README	2007-12-12 21:14:14 UTC (rev 14300)
@@ -9,7 +9,7 @@
 
 usage right now:
  ./ffmpeg2theora clip.avi
- will produce clip.ogg
+ will produce clip.ogv
  for more options run ffmpeg2theora -h
 
  there is a export plugin for kino (http://kino.schirmacher.de/)

Modified: trunk/ffmpeg2theora/ffmpeg2theora.1
===================================================================
--- trunk/ffmpeg2theora/ffmpeg2theora.1	2007-12-12 19:44:40 UTC (rev 14299)
+++ trunk/ffmpeg2theora/ffmpeg2theora.1	2007-12-12 21:14:14 UTC (rev 14300)
@@ -33,7 +33,7 @@
 .TP
 .B \-o, \-\-output
 Specify the output filename.  If no output filename is specified, output will
-be written to \fIinputfile\fP.ogg.  To output to standard output, specify
+be written to \fIinputfile\fP.ogv.  To output to standard output, specify
 /dev/stdout as the output file.
 .TP
 .B \-s, \-\-starttime
@@ -176,24 +176,24 @@
 Output a help message.
 .SH EXAMPLES
 Encode Videos:
-  ffmpeg2theora videoclip.avi (will write output to videoclip.ogg)
+  ffmpeg2theora videoclip.avi (will write output to videoclip.ogv)
   
-  cat something.dv | ffmpeg2theora -f dv -o output.ogg \-
+  cat something.dv | ffmpeg2theora -f dv -o output.ogv \-
 
 Encode a series of images:
-  ffmpeg2theora -f image2 frame%06d.png -o output.ogg
+  ffmpeg2theora -f image2 frame%06d.png -o output.ogv
 
 Live streaming from V4L Device:
   ffmpeg2theora \-\-v4l /dev/video0 \-\-inputfps 15 \-x 160 \-y 128 \-o \- \\
-    | oggfwd iccast2server 8000 password /theora.ogg
+    | oggfwd iccast2server 8000 password /theora.ogv
 
 Live encoding from a DV camcorder (needs a fast machine):
-  dvgrab - | ffmpeg2theora -f dv -x 352 -y 288 -o output.ogg -\n"
+  dvgrab - | ffmpeg2theora -f dv -x 352 -y 288 -o output.ogv -\n"
 
 Live encoding and streaming to icecast server:
   dvgrab \-\-format raw \- \\
     | ffmpeg2theora \-f dv \-x 160 \-y 128 \-o /dev/stdout \- \\
-    | oggfwd iccast2server 8000 password /theora.ogg
+    | oggfwd iccast2server 8000 password /theora.ogv
 
 
 .SH AUTHOR

Modified: trunk/ffmpeg2theora/ffmpeg2theora.c
===================================================================
--- trunk/ffmpeg2theora/kino_export/ffmpeg2theora.sh	2007-12-12 19:44:40 UTC (rev 14299)
+++ trunk/ffmpeg2theora/kino_export/ffmpeg2theora.sh	2007-12-12 21:14:14 UTC (rev 14300)
@@ -37,10 +37,10 @@
 
 	# Run the command
 	case "$profile" in 
-		"0" ) 	ffmpeg2theora -f dv -x 640 -y 480 -d -v 7 -a 3 -H 48000 -o "$file".ogg - ;;
-		"1" ) 	ffmpeg2theora -f dv -x 320 -y 240 -d -v 7 -a 3 -H 48000 -o "$file".ogg - ;;
-		"2" ) 	ffmpeg2theora -f dv -x 320 -y 240 -d -v 5 -a 0 -H 44100 -o "$file".ogg - ;;
-		"3" ) 	ffmpeg2theora -f dv -x 160 -y 128 -d -v 3 -a 0 -H 22000 -o "$file".ogg - ;;
+		"0" ) 	ffmpeg2theora -f dv -x 640 -y 480 -d -v 7 -a 3 -H 48000 -o "$file".ogv - ;;
+		"1" ) 	ffmpeg2theora -f dv -x 320 -y 240 -d -v 7 -a 3 -H 48000 -o "$file".ogv - ;;
+		"2" ) 	ffmpeg2theora -f dv -x 320 -y 240 -d -v 5 -a 0 -H 44100 -o "$file".ogv - ;;
+		"3" ) 	ffmpeg2theora -f dv -x 160 -y 128 -d -v 3 -a 0 -H 22000 -o "$file".ogv - ;;
 	esac
 }
 



More information about the commits mailing list
--- trunk/ffmpeg2theora/ffmpeg2theora.c	2007-12-12 19:44:40 UTC (rev 14299)
+++ trunk/ffmpeg2theora/ffmpeg2theora.c	2007-12-12 21:14:14 UTC (rev 14300)
@@ -1079,26 +1079,26 @@
         "  -h, --help             this message\n"
         "\n"
         "Examples:\n"
-        "  ffmpeg2theora videoclip.avi (will write output to videoclip.ogg)\n"
+        "  ffmpeg2theora videoclip.avi (will write output to videoclip.ogv)\n"
         "\n"
-        "  cat something.dv | ffmpeg2theora -f dv -o output.ogg -\n"
+        "  cat something.dv | ffmpeg2theora -f dv -o output.ogv -\n"
         "\n"
         "  Encode a series of images:\n"
-        "    ffmpeg2theora -f image2 frame%%06d.png -o output.ogg\n"
+        "    ffmpeg2theora -f image2 frame%%06d.png -o output.ogv\n"
         "\n"
 #ifdef VIDEO4LINUX_ENABLED
         "  Live streaming from V4L Device:\n"
         "    ffmpeg2theora --v4l /dev/video0 --inputfps 15 -x 160 -y 128 -o - \\\n"
-        "     | oggfwd iccast2server 8000 password /theora.ogg\n"
+        "     | oggfwd iccast2server 8000 password /theora.ogv\n"
         "\n"
 #endif
         "  Live encoding from a DV camcorder (needs a fast machine):\n"
-        "    dvgrab - | ffmpeg2theora -f dv -x 352 -y 288 -o output.ogg -\n"
+        "    dvgrab - | ffmpeg2theora -f dv -x 352 -y 288 -o output.ogv -\n"
         "\n"
         "  Live encoding and streaming to icecast server:\n"
         "    dvgrab --format raw - \\\n"
         "     | ffmpeg2theora -f dv -x 160 -y 128 -o /dev/stdout - \\\n"
-        "     | oggfwd iccast2server 8000 password /theora.ogg\n"
+        "     | oggfwd iccast2server 8000 password /theora.ogv\n"
         "\n"
         );
     exit (0);
@@ -1454,16 +1454,16 @@
             snprintf(inputfile_name,sizeof(inputfile_name),"pipe:");
         }
         if(outputfile_set!=1){
             /* reserve 4 bytes in the buffer for the `.ogg' extension */
             snprintf(outputfile_name, sizeof(outputfile_name) - 4, "%s", argv[optind]);
             if((str_ptr = strrchr(outputfile_name, '.'))) {
-              sprintf(str_ptr, ".ogg");
+              sprintf(str_ptr, ".ogv");
               if(!strcmp(inputfile_name, outputfile_name)){
-                snprintf(outputfile_name, sizeof(outputfile_name), "%s.ogg", inputfile_name);
+                snprintf(outputfile_name, sizeof(outputfile_name), "%s.ogv", inputfile_name);
               }
             }
             else {
-                 snprintf(outputfile_name, sizeof(outputfile_name), "%s.ogg", outputfile_name);
+                 snprintf(outputfile_name, sizeof(outputfile_name), "%s.ogv", outputfile_name);
             }
             outputfile_set=1;
         }
@@ -1499,7 +1499,7 @@
                    !strcmp( inputfile_name, "/dev/stdin" );
 
     if(outputfile_set!=1){    
-        fprintf(stderr,"You have to specify an output file with -o output.ogg.\n");    
+        fprintf(stderr,"You have to specify an output file with -o output.ogv.\n");    
         exit(1);
     }
 
@@ -1454,16 +1454,16 @@
         }
         if(outputfile_set!=1){
-            /* reserve 4 bytes in the buffer for the `.ogg' extension */
+            /* reserve 4 bytes in the buffer for the `.ogv' extension */
             snprintf(outputfile_name, sizeof(outputfile_name) - 4, "%s", argv[optind]);
             if((str_ptr = strrchr(outputfile_name, '.'))) {

Modified: trunk/ffmpeg2theora/kino_export/ffmpeg2theora.sh
===================================================================